@@ -46,6 +46,7 @@
 #endif
 
 #include "functions.h"
+#include "afterstep.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -110,7 +111,9 @@ typedef struct CommandLineOpts
     ASFlagType flags;
 }CommandLineOpts;
 
-extern CommandLineOpts as_standard_cmdl_options[20];/* really its terminated by NULL element */
+#define STANDARD_CMDL_OPTS_NUM 22
+
+extern CommandLineOpts as_standard_cmdl_options[STANDARD_CMDL_OPTS_NUM];/* really its terminated by NULL element */
 
 void  print_command_line_opt(const char *prompt, CommandLineOpts *options, ASFlagType mask);
 int   match_command_line_opt( char *argvi, CommandLineOpts *options );
@@ -119,6 +122,8 @@ void  handler_show_info( char *argv, void *trg, long param );
 void  handler_set_flag( char *argv, void *trg, long param );
 void  handler_set_string( char *argv, void *trg, long param );
 void  handler_set_int( char *argv, void *trg, long param );
+void  handler_set_geometry( char *argv, void *trg, long param );
+void  handler_set_gravity( char *argv, void *trg, long param );
 
 
 typedef struct ASProgArgs
@@ -159,10 +164,16 @@ typedef struct ASProgArgs
     char      *log_file ;
     char      *locale ;
 
+	ASGeometry geometry;
+	int gravity ;
+
 }ASProgArgs;
 
 typedef struct ASEnvironment
 {
+#define ASE_NoSharedMemory		(0x01<<0)
+  ASFlagType flags ; 
+
   char *module_path;
   char *audio_path;
   char *icon_path;
@@ -171,6 +182,8 @@ typedef struct ASEnvironment
   char *cursor_path;
   unsigned short desk_pages_h, desk_pages_v ;
   unsigned short desk_scale ;
+
+  char *term_command ;
 }ASEnvironment;
 
 /*
@@ -279,8 +292,12 @@ extern int SingleScreen ;                              /* if >= 0 then [points t
 extern unsigned int  NumberOfScreens;   			   /* number of screens on display */
 extern int PointerScreen ;							   /* screen that currently has pointer */
 
-extern struct TermDef       FuncTerms[F_FUNCTIONS_NUM + 1];
-extern struct SyntaxDef FuncSyntax, *pFuncSyntax ;
+enum FunctionCode;
+
+extern struct SyntaxDef *pFuncSyntax ;
+extern struct SyntaxDef *pPopupFuncSyntax;
+
+struct TermDef  *func2fterm (enum FunctionCode func, int quiet);
 
 extern struct ASSession *Session;          /* filenames of look, feel and background */
 extern struct ASEnvironment *Environment;
