@@ -45,6 +45,7 @@
 #include "screen.h"
 #include "freestor.h"
 #include "functions.h"
+#include "../libAfterImage/asimagexml.h"
 
 extern char  *_disabled_keyword;
 #if 0
@@ -218,13 +219,9 @@ AddFreeStorageElem (SyntaxDef * syntax, FreeStorageElem ** tail, TermDef * pterm
 
 	if (pterm)
 	{
-		new_elem = (FreeStorageElem *) safemalloc (sizeof (FreeStorageElem));
+		new_elem = (FreeStorageElem *) safecalloc (1, sizeof (FreeStorageElem));
 		new_elem->term = pterm;
-		new_elem->argc = 0;
-		new_elem->argv = NULL;
-		new_elem->flags = 0;
 		new_elem->next = *tail;
-		new_elem->sub = NULL;
 		*tail = new_elem;
 	}
 	return new_elem;
@@ -238,14 +235,12 @@ DupFreeStorageElem (FreeStorageElem * source)
 
 	if (source)
 	{
-		new_elem = (FreeStorageElem *) safemalloc (sizeof (FreeStorageElem));
+		new_elem = (FreeStorageElem *) safecalloc (1, sizeof (FreeStorageElem));
 		new_elem->term = source->term;
 		new_elem->argc = source->argc;
 		/* duplicating argv here */
 		new_elem->argv = DupStringArray (source->argc, source->argv);
 		new_elem->flags = source->flags;
-		new_elem->next = NULL;
-		new_elem->sub = NULL;
 		if (new_elem->sub)
 		{
 			FreeStorageElem *psub, **pnew_sub = &(new_elem->sub);
@@ -436,8 +431,7 @@ free_storage2func (FreeStorageElem * stored, int *ppos)
 	if (stored->term == NULL)
 		return NULL;
 
-	pfunc = (struct FunctionData *)safemalloc (sizeof (struct FunctionData));
-	memset (pfunc, 0x00, sizeof (struct FunctionData));
+	pfunc = (struct FunctionData *)safecalloc (1, sizeof (struct FunctionData));
 
 	pfunc->func = stored->term->id;
 
@@ -575,11 +569,11 @@ free_storage2box (FreeStorageElem * stored, int *ppos, ASBox * pbox)
 Bool
 free_storage2geometry (FreeStorageElem * stored, int *ppos, ASGeometry * pgeometry)
 {
-	char *geom = stored->argv[*(ppos++)];
+	char *geom = stored->argv[(*ppos)++];
 
 	if (pgeometry == NULL || geom == NULL )
 		return False;
-
+	memset( pgeometry, 0x00, sizeof(ASGeometry)) ;
 	parse_geometry ( geom,
 	                &(pgeometry->x), &(pgeometry->y),
 					&(pgeometry->width), &(pgeometry->height),
@@ -1019,12 +1013,15 @@ ReadConfigItem (ConfigItem * item, FreeStorageElem * stored)
 		 case TT_UINTEGER:
 			 if (!check_avail_args (stored, pos, 1))
 				 return 0;
+#if 0
 			 if( !isdigit(stored->argv[pos][0]) && stored->argv[pos][0] != '-' )
 			 {
 
 
 			 }else
 			 	item->data.integer = atol (stored->argv[pos]);
+#endif
+			 item->data.integer = parse_math(stored->argv[pos], NULL, 0);
 			 ++pos ;
 			 if (stored->term->type == TT_UINTEGER && item->data.integer < 0)
 			 {
