@@ -88,17 +88,26 @@ make_component_hilite (int cmp)
 inline        ARGB32
 GetHilite (ARGB32 background)
 {
-	return ((make_component_hilite ((background>>24) & 0x000000FF) << 24) & 0xFF000000) |
-		((make_component_hilite ((background & 0x00FF0000) >> 16) << 16) & 0x00FF0000) |
-		((make_component_hilite ((background & 0x0000FF00) >> 8) << 8) & 0x0000FF00) |
-		((make_component_hilite ((background & 0x000000FF))) & 0x000000FF);
+	CARD32 a = make_component_hilite (ARGB32_ALPHA8 (background));
+	CARD32 r = make_component_hilite (ARGB32_RED8 (background));
+	CARD32 g = make_component_hilite (ARGB32_GREEN8 (background));
+	CARD32 b = make_component_hilite (ARGB32_BLUE8 (background));
+
+	return MAKE_ARGB32 (a, r, g, b);
 }
 
 /* This routine computes the shadow color from the background color */
 inline        ARGB32
 GetShadow (ARGB32 background)
 {
-	return (background >> 1) & 0x7F7F7F7F;
+	CARD16        a, r, g, b;
+
+	a = (ARGB32_ALPHA8 (background))*3/4;
+	r = (ARGB32_RED8 (background))*3/4;
+	g = (ARGB32_GREEN8 (background))*3/4;
+	b = (ARGB32_BLUE8 (background))*3/4;
+	
+	return MAKE_ARGB32 (a, r, g, b);
 }
 
 inline        ARGB32
@@ -106,14 +115,10 @@ GetAverage (ARGB32 foreground, ARGB32 background)
 {
 	CARD16        a, r, g, b;
 
-	a = ARGB32_ALPHA8 (foreground) + ARGB32_ALPHA8 (background);
-	a = (a<<3)/10;
-	r = ARGB32_RED8 (foreground) + ARGB32_RED8 (background);
-	r = (r<<3)/10;
-	g = ARGB32_GREEN8 (foreground) + ARGB32_GREEN8 (background);
-	g = (g<<3)/10;
-	b = ARGB32_BLUE8 (foreground) + ARGB32_BLUE8 (background);
-	b = (b<<3)/10;
+	a = (ARGB32_ALPHA8 (foreground) + ARGB32_ALPHA8 (background))/2;
+	r = (ARGB32_RED8 (foreground) + ARGB32_RED8 (background))/2;
+	g = (ARGB32_GREEN8 (foreground) + ARGB32_GREEN8 (background))/2;
+	b = (ARGB32_BLUE8 (foreground) + ARGB32_BLUE8 (background))/2;
 	return MAKE_ARGB32 (a, r, g, b);
 }
 
@@ -127,7 +132,7 @@ mystyle_list_fix_styles (ASHashTable *list)
     ASHashIterator iterator ;
 
     if( list == NULL )
-        if( (list = Scr.Look.styles_list) == NULL )
+        if( (list = ASDefaultScr->Look.styles_list) == NULL )
             return;
 
 /*
@@ -240,7 +245,7 @@ grab_root_asimage( ScreenInfo *scr, Window target, Bool screenshot )
 	int width = scr->RootClipArea.width, height = scr->RootClipArea.height ;
 
 	if( scr == NULL )
-		scr = &Scr ;
+		scr = ASDefaultScr ;
 	/* this only works if we use DefaultVisual - same visual as the Root window :*/
 	if( scr->asv->visual_info.visual != DefaultVisual( dpy, DefaultScreen(dpy) ) )
 		return NULL ;
@@ -273,10 +278,10 @@ grab_root_asimage( ScreenInfo *scr, Window target, Bool screenshot )
 		height += y ;
 		y = 0 ;
 	}
-	if( x + width > Scr.MyDisplayWidth )
-		width = (int)(Scr.MyDisplayWidth) - x ;
-	if( y + height > Scr.MyDisplayHeight )
-		height = (int)(Scr.MyDisplayHeight) - y ;
+	if( x + width > ASDefaultScrWidth )
+		width = (int)(ASDefaultScrWidth) - x ;
+	if( y + height > ASDefaultScrHeight )
+		height = (int)(ASDefaultScrHeight) - y ;
 
 	if( height < 0 || width < 0 )
 		return NULL ;
@@ -370,7 +375,7 @@ mystyle_flip_image( ASImage *im, int width, int height, int flip )
 	ASImage *tmp ;
 	if(flip == 0)
 		return im;
-	tmp = flip_asimage( Scr.asv, im, 0, 0, width, height, flip, ASA_ASImage, 100, ASIMAGE_QUALITY_DEFAULT );
+	tmp = flip_asimage( ASDefaultVisual, im, 0, 0, width, height, flip, ASA_ASImage, 100, ASIMAGE_QUALITY_DEFAULT );
 	if( tmp != NULL )
 	{
 		safe_asimage_destroy( im );
@@ -379,12 +384,69 @@ mystyle_flip_image( ASImage *im, int width, int height, int flip )
 	return im;
 }
 
+static ASImage *
+clip_root_pixmap( Pixmap root_pixmap, int width, int height )
+{
+	ASImage *result = NULL ;
+	XRectangle *clip_area = &(ASDefaultScr->RootClipArea) ; 
+
+	if (root_pixmap)
+	{
+    	ASImage *tmp_root ;
+		int root_x = 0, root_y = 0 ;
+		int clip_x = clip_area->x ;
+		int clip_y = clip_area->y ;
+
+		while( clip_x < 0 )
+			clip_x += ASDefaultScrWidth ;
+		clip_x %= width ;
+		while( clip_y < 0 )
+			clip_y += ASDefaultScrHeight ;
+		clip_y %= height ;
+
+		/* at this point clip_x and clip_y fall into root pixmap */
+
+		if( clip_x + clip_area->width  <= width  ) 
+		{
+			root_x = clip_x ; 
+			width = clip_area->width ;
+		}
+		if( clip_y + clip_area->height <= height  ) 
+		{
+			root_y = clip_y ; 
+			height = clip_area->height  ;
+		}
+		/* fprintf( stderr, "RootPixmap2RootImage %dx%d%+d%+d", root_w, root_h, root_x,
+		root_y); */
+    	tmp_root = pixmap2asimage (ASDefaultVisual, root_pixmap, root_x, root_y, width, height, AllPlanes, False, 100);
+
+		LOCAL_DEBUG_OUT ("Root pixmap ASImage = %p, size = %dx%d", tmp_root, tmp_root?tmp_root->width:0, tmp_root?tmp_root->height:0);
+    	if( tmp_root )
+    	{
+        	if( clip_x == root_x && clip_y == root_y &&
+            	clip_area->width == width && clip_area->height == height )
+        	{
+            	result = tmp_root ;
+        	}else
+        	{
+            	result = tile_asimage ( ASDefaultVisual, tmp_root,
+										(clip_x == root_x)?0:clip_area->x, 
+										(clip_y == root_y)?0:clip_area->y,
+                                        clip_area->width, clip_area->height, TINT_NONE,
+                                        ASA_ASImage, 100, ASIMAGE_QUALITY_DEFAULT);
+            	destroy_asimage( &tmp_root );
+        	}
+    	}
+    }
+	return result;
+}	 
+
+
 ASImage      *
 mystyle_make_image (MyStyle * style, int root_x, int root_y, int width, int height, int flip )
 {
 	ASImage      *im = NULL;
 	Pixmap        root_pixmap;
-	unsigned int  root_w, root_h;
 	Bool transparency = False ;
 	int preflip_width, preflip_height ;
 
@@ -399,69 +461,17 @@ mystyle_make_image (MyStyle * style, int root_x, int root_y, int width, int heig
 
 	if(  transparency )
 	{	/* in this case we need valid root image : */
-		 if (Scr.RootImage == NULL)
-		 {
-			 root_pixmap = ValidatePixmap (None, 1, 1, &root_w, &root_h);
-			 LOCAL_DEBUG_OUT ("obtained Root pixmap = %lX", root_pixmap);
-			 if (root_pixmap)
-			 {
-                ASImage *tmp_root ;
-				int root_x = 0, root_y = 0 ;
-
-				if( Scr.RootClipArea.x + Scr.RootClipArea.width  < (int)root_w  ) 
-				{
-					if( Scr.RootClipArea.x > 0 ) 
-						root_x = Scr.RootClipArea.x ; 
-					root_w = (Scr.RootClipArea.x + Scr.RootClipArea.width) - root_x ;
-					if( root_w < 0 ) 
-						root_w = 1;
-				}
-				if( Scr.RootClipArea.y + Scr.RootClipArea.height  < (int)root_h  ) 
-				{
-					if( Scr.RootClipArea.y > 0 ) 
-						root_y = Scr.RootClipArea.y ; 
-					root_h = (Scr.RootClipArea.y + Scr.RootClipArea.height ) - root_y ;
-					if( root_h < 0 ) 
-						root_h = 1;
-				}
-				/* fprintf( stderr, "RootPixmap2RootImage %dx%d%+d%+d", root_w, root_h, root_x,
-				root_y); */
-                tmp_root = pixmap2asimage (Scr.asv, root_pixmap, root_x, root_y, root_w, root_h, AllPlanes, False, 100);
-
-				LOCAL_DEBUG_OUT ("Root pixmap ASImage = %p, size = %dx%d", tmp_root, tmp_root?tmp_root->width:0, tmp_root?tmp_root->height:0);
-                if( tmp_root )
-                {
-                    if( Scr.RootClipArea.x == root_x && Scr.RootClipArea.y == root_y &&
-                        Scr.RootClipArea.width == root_w && Scr.RootClipArea.height == root_h )
-                    {
-                        Scr.RootImage = tmp_root ;
-                    }else
-                    {
-                        Scr.RootImage = tile_asimage (Scr.asv, tmp_root,
-											(Scr.RootClipArea.x<0)?root_x-Scr.RootClipArea.x: 
-																   Scr.RootClipArea.x - root_x, 
-											(Scr.RootClipArea.y<0)?root_y - Scr.RootClipArea.y:
-																   Scr.RootClipArea.y - root_y,
-                                                    Scr.RootClipArea.width, Scr.RootClipArea.height, TINT_NONE,
-                                                    ASA_ASImage, 100, ASIMAGE_QUALITY_DEFAULT);
-                        destroy_asimage( &tmp_root );
-                    }
-                }
-             }
-             if( Scr.RootImage == NULL )
-             {
-                if( (Scr.RootImage = grab_root_asimage( &Scr, None, False )) != NULL )
-                {
-                    root_w = Scr.RootImage->width;
-                    root_h = Scr.RootImage->height;
-                }
-             }
-		 } else
-		 {
-			 root_w = Scr.RootImage->width;
-			 root_h = Scr.RootImage->height;
-		 }
-         LOCAL_DEBUG_OUT ("RootImage = %p clip(%ux%u%+d%+d) size(%dx%d)", Scr.RootImage, Scr.RootClipArea.width, Scr.RootClipArea.height, Scr.RootClipArea.x, Scr.RootClipArea.y, Scr.RootImage?Scr.RootImage->width:0, Scr.RootImage?Scr.RootImage->height:0);
+		if (ASDefaultScr->RootImage == NULL)
+		{
+			unsigned int  root_w, root_h;
+			root_pixmap = ValidatePixmap (None, 1, 1, &root_w, &root_h);
+			LOCAL_DEBUG_OUT ("obtained Root pixmap = %lX", root_pixmap);
+			ASDefaultScr->RootImage = clip_root_pixmap( root_pixmap, root_w, root_h );
+             
+			if( ASDefaultScr->RootImage == NULL )
+                ASDefaultScr->RootImage = grab_root_asimage( ASDefaultScr, None, False );
+		}
+        LOCAL_DEBUG_OUT ("RootImage = %p clip(%ux%u%+d%+d) size(%dx%d)", ASDefaultScr->RootImage, ASDefaultScr->RootClipArea.width, ASDefaultScr->RootClipArea.height, ASDefaultScr->RootClipArea.x, ASDefaultScr->RootClipArea.y, ASDefaultScr->RootImage?ASDefaultScr->RootImage->width:0, ASDefaultScr->RootImage?ASDefaultScr->RootImage->height:0);
 	}
 	if( get_flags( flip, FLIP_VERTICAL )  )
 	{
@@ -494,7 +504,7 @@ mystyle_make_image (MyStyle * style, int root_x, int root_y, int width, int heig
 	 	{
 			ASGradient *grad = flip_gradient( &(style->gradient), flip );
  			LOCAL_DEBUG_OUT( "orig grad type = %d, translated grad_type = %d, texture_type = %d", style->gradient.type, grad->type, style->texture_type );
-		 	im = make_gradient (Scr.asv, grad, width, height, 0xFFFFFFFF, ASA_ASImage, 0,
+		 	im = make_gradient (ASDefaultVisual, grad, width, height, 0xFFFFFFFF, ASA_ASImage, 0,
 							 ASIMAGE_QUALITY_DEFAULT);
 			if( grad != &(style->gradient) )
 				destroy_asgradient( &grad );
@@ -502,13 +512,20 @@ mystyle_make_image (MyStyle * style, int root_x, int root_y, int width, int heig
 		break;
 	 case TEXTURE_SHAPED_SCALED_PIXMAP:
 	 case TEXTURE_SCALED_PIXMAP:
-		 im = scale_asimage (Scr.asv, style->back_icon.image, preflip_width, preflip_height, ASA_ASImage, 0, ASIMAGE_QUALITY_DEFAULT);
-		 if( flip != 0 )
-		 	im = mystyle_flip_image( im, width, height, flip );
-		 break;
+	 	if( get_flags( style->set_flags, F_SLICE ) )
+		{
+			im = slice_asimage (ASDefaultVisual, style->back_icon.image, 
+								style->slice_x_start, style->slice_x_end,
+								style->slice_y_start, style->slice_y_end,
+								preflip_width, preflip_height, ASA_ASImage, 0, ASIMAGE_QUALITY_DEFAULT);			   
+		}else	 
+			im = scale_asimage (ASDefaultVisual, style->back_icon.image, preflip_width, preflip_height, ASA_ASImage, 0, ASIMAGE_QUALITY_DEFAULT);
+		if( flip != 0 )
+			im = mystyle_flip_image( im, width, height, flip );
+		break;
 	 case TEXTURE_SHAPED_PIXMAP:
 	 case TEXTURE_PIXMAP:
-		 im = tile_asimage (Scr.asv, style->back_icon.image,
+		 im = tile_asimage (ASDefaultVisual, style->back_icon.image,
 							0, 0, preflip_width, preflip_height, TINT_LEAVE_SAME, ASA_ASImage, 0, ASIMAGE_QUALITY_DEFAULT);
 		 LOCAL_DEBUG_OUT( "back_icon.image = %p,im = %p, preflip_size=%dx%d", style->back_icon.image, im, preflip_width, preflip_height );
 		 if( flip != 0 )
@@ -518,11 +535,11 @@ mystyle_make_image (MyStyle * style, int root_x, int root_y, int width, int heig
 
 	if( transparency )
 	{
-		if (Scr.RootImage != NULL)
+		if (ASDefaultScr->RootImage != NULL)
 		{
 			if (style->texture_type == TEXTURE_TRANSPARENT || style->texture_type == TEXTURE_TRANSPARENT_TWOWAY)
 			{
-                im = tile_asimage (Scr.asv, Scr.RootImage, root_x-Scr.RootClipArea.x, root_y-Scr.RootClipArea.y,
+                im = tile_asimage (ASDefaultVisual, ASDefaultScr->RootImage, root_x-ASDefaultScr->RootClipArea.x, root_y-ASDefaultScr->RootClipArea.y,
 									width, height, style->tint, ASA_ASImage, 0, ASIMAGE_QUALITY_DEFAULT);
 			} else
 			{
@@ -532,7 +549,7 @@ mystyle_make_image (MyStyle * style, int root_x, int root_y, int width, int heig
 
 				 init_image_layers (&layers[0], 2);
 
-				 layers[0].im = Scr.RootImage;
+				 layers[0].im = ASDefaultScr->RootImage;
 				 if (style->texture_type == TEXTURE_SHAPED_SCALED_PIXMAP &&
 					 style->texture_type == TEXTURE_SHAPED_PIXMAP)
 				 {
@@ -547,8 +564,8 @@ mystyle_make_image (MyStyle * style, int root_x, int root_y, int width, int heig
 				 layers[0].merge_scanlines = mystyle_merge_scanlines_func_xref[index];
                  layers[0].dst_x = 0;
                  layers[0].dst_y = 0;
-                 layers[0].clip_x = root_x-Scr.RootClipArea.x;
-                 layers[0].clip_y = root_y-Scr.RootClipArea.y;
+                 layers[0].clip_x = root_x-ASDefaultScr->RootClipArea.x;
+                 layers[0].clip_y = root_y-ASDefaultScr->RootClipArea.y;
 				 layers[0].clip_width = width;
 				 layers[0].clip_height = height;
 
@@ -556,8 +573,15 @@ mystyle_make_image (MyStyle * style, int root_x, int root_y, int width, int heig
 				 if (style->texture_type >= TEXTURE_SCALED_TRANSPIXMAP &&
 					 style->texture_type < TEXTURE_SCALED_TRANSPIXMAP_END)
 				 {
-					 scaled_im = scale_asimage (Scr.asv, layers[1].im, preflip_width, preflip_height,
-												ASA_ASImage, 0, ASIMAGE_QUALITY_DEFAULT);
+				 	if( get_flags( style->set_flags, F_SLICE ) )
+					{
+						scaled_im = slice_asimage (ASDefaultVisual, layers[1].im, 
+												style->slice_x_start, style->slice_x_end,
+												style->slice_y_start, style->slice_y_end,
+												preflip_width, preflip_height, ASA_ASImage, 0, ASIMAGE_QUALITY_DEFAULT);			   
+					}else	 
+						 scaled_im = scale_asimage (ASDefaultVisual, layers[1].im, preflip_width, preflip_height,
+													ASA_ASImage, 0, ASIMAGE_QUALITY_DEFAULT);
 					 /* here layers[1].im is always style->back_icon.image, so we should not destroy it ! */
 					 if (scaled_im)
 						 layers[1].im = mystyle_flip_image( scaled_im, width, height, flip );
@@ -566,7 +590,7 @@ mystyle_make_image (MyStyle * style, int root_x, int root_y, int width, int heig
 				 if( flip != 0 && layers[1].im == style->back_icon.image )
 				 {
 					/* safely assuming that im is NULL at this point,( see logic above ) */
-					 layers[1].im = im = flip_asimage( Scr.asv, layers[1].im, 0, 0, width, height, flip, ASA_ASImage, 100, ASIMAGE_QUALITY_DEFAULT );
+					 layers[1].im = im = flip_asimage( ASDefaultVisual, layers[1].im, 0, 0, width, height, flip, ASA_ASImage, 100, ASIMAGE_QUALITY_DEFAULT );
 				 }
 				 layers[1].merge_scanlines = layers[0].merge_scanlines;
 				 layers[1].dst_x = 0;
@@ -577,7 +601,7 @@ mystyle_make_image (MyStyle * style, int root_x, int root_y, int width, int heig
 				 layers[1].clip_height = height;
 
 				{
-					ASImage *tmp = merge_layers (Scr.asv, &layers[0], 2, width, height, ASA_ASImage, 0, ASIMAGE_QUALITY_DEFAULT);
+					ASImage *tmp = merge_layers (ASDefaultVisual, &layers[0], 2, width, height, ASA_ASImage, 0, ASIMAGE_QUALITY_DEFAULT);
 					if( tmp )
 					{
 						if( im )
@@ -699,9 +723,9 @@ mystyle_list_new (struct ASHashTable *list, char *name)
 
     if( list == NULL )
     {
-        if( Scr.Look.styles_list == NULL )
-            if( (Scr.Look.styles_list = mystyle_list_init())== NULL ) return NULL;
-        list = Scr.Look.styles_list ;
+        if( ASDefaultScr->Look.styles_list == NULL )
+            if( (ASDefaultScr->Look.styles_list = mystyle_list_init())== NULL ) return NULL;
+        list = ASDefaultScr->Look.styles_list ;
     }
 
     if( get_hash_item( list, AS_HASHABLE(name), &hdata.vptr ) == ASH_Success )
@@ -744,7 +768,7 @@ void
 mystyle_list_destroy_all( ASHashTable **plist )
 {
     if( plist == NULL )
-        plist = &Scr.Look.styles_list ;
+        plist = &(ASDefaultScr->Look.styles_list) ;
     destroy_ashash( plist );
 }
 
@@ -763,7 +787,7 @@ mystyle_list_find (struct ASHashTable *list, const char *name)
 {
     ASHashData hdata = {0};
     if( list == NULL )
-        list = Scr.Look.styles_list ;
+        list = ASDefaultScr->Look.styles_list ;
 
     if( list && name )
         if( get_hash_item( list, AS_HASHABLE((char*)name), &hdata.vptr ) != ASH_Success )
@@ -777,7 +801,7 @@ mystyle_list_find_or_default (struct ASHashTable *list, const char *name)
     ASHashData hdata = {0};
 
     if( list == NULL )
-        list = Scr.Look.styles_list ;
+        list = ASDefaultScr->Look.styles_list ;
 
     if( name == NULL )
         name = DefaultMyStyleName ;
@@ -890,19 +914,22 @@ mystyle_merge_styles (MyStyle * parent, MyStyle * child, Bool override, Bool cop
 			}
 		}
 	}
-	if (parent->set_flags & F_MAXCOLORS)
+	if (parent->set_flags & F_SLICE)
 	{
-		if ((override == True) || !(child->set_flags & F_MAXCOLORS))
+		if ((override == True) || !(child->set_flags & F_SLICE))
 		{
-			child->max_colors = parent->max_colors;
+			child->slice_x_start = parent->slice_x_start;
+			child->slice_x_end = parent->slice_x_end;
+			child->slice_y_start = parent->slice_y_start;
+			child->slice_y_end = parent->slice_y_end;
 			if (copy == False)
 			{
-				child->user_flags &= ~F_MAXCOLORS;
-				child->inherit_flags |= F_MAXCOLORS;
+				child->user_flags &= ~F_SLICE;
+				child->inherit_flags |= F_SLICE;
 			} else
 			{
-				child->user_flags |= F_MAXCOLORS;
-				child->inherit_flags &= ~F_MAXCOLORS;
+				child->user_flags |= F_SLICE;
+				child->inherit_flags &= ~F_SLICE;
 			}
 		}
 	}
@@ -951,11 +978,11 @@ mystyle_merge_styles (MyStyle * parent, MyStyle * child, Bool override, Bool cop
 					set_flags (child->inherit_flags, F_BACKTRANSPIXMAP);
 			} else
 			{
-				GC            gc = create_visual_gc (Scr.asv, Scr.Root, 0, NULL);
+				GC            gc = create_visual_gc (ASDefaultVisual, ASDefaultRoot, 0, NULL);
 
 				child->back_icon.pix =
-					XCreatePixmap (dpy, Scr.Root, parent->back_icon.width, parent->back_icon.height,
-								   Scr.asv->visual_info.depth);
+					XCreatePixmap (dpy, ASDefaultRoot, parent->back_icon.width, parent->back_icon.height,
+								   ASDefaultVisual->visual_info.depth);
 				XCopyArea (dpy, parent->back_icon.pix, child->back_icon.pix, gc, 0, 0, parent->back_icon.width,
 						   parent->back_icon.height, 0, 0);
 				if (parent->back_icon.mask != None)
@@ -963,7 +990,7 @@ mystyle_merge_styles (MyStyle * parent, MyStyle * child, Bool override, Bool cop
 					GC            mgc = XCreateGC (dpy, parent->back_icon.mask, 0, NULL);
 
 					child->back_icon.mask =
-						XCreatePixmap (dpy, Scr.Root, parent->back_icon.width, parent->back_icon.height, 1);
+						XCreatePixmap (dpy, ASDefaultRoot, parent->back_icon.width, parent->back_icon.height, 1);
 					XCopyArea (dpy, parent->back_icon.mask, child->back_icon.mask, mgc, 0, 0, parent->back_icon.width,
 							   parent->back_icon.height, 0, 0);
 					XFreeGC (dpy, mgc);
@@ -973,7 +1000,7 @@ mystyle_merge_styles (MyStyle * parent, MyStyle * child, Bool override, Bool cop
 					GC            mgc = XCreateGC (dpy, parent->back_icon.alpha, 0, NULL);
 
 					child->back_icon.alpha =
-						XCreatePixmap (dpy, Scr.Root, parent->back_icon.width, parent->back_icon.height, 8);
+						XCreatePixmap (dpy, ASDefaultRoot, parent->back_icon.width, parent->back_icon.height, 8);
 					XCopyArea (dpy, parent->back_icon.alpha, child->back_icon.alpha, mgc, 0, 0, parent->back_icon.width,
 							   parent->back_icon.height, 0, 0);
 					XFreeGC (dpy, mgc);
@@ -1130,7 +1157,7 @@ mystyle_merge_colors (MyStyle * style, int type, char *fore, char *back,
 		if (pixmap != NULL)
 		{
 /* treat second parameter as an image filename : */
-            if ( load_icon(&(style->back_icon), pixmap, Scr.image_manager ))
+            if ( load_icon(&(style->back_icon), pixmap, ASDefaultScr->image_manager ))
             {
                 style->texture_type = type;
                 set_flags(style->user_flags, F_BACKPIXMAP);
@@ -1179,27 +1206,30 @@ mystyle_make_bevel (MyStyle * style, ASImageBevel * bevel, int hilite, Bool reve
 			bevel->lo_color = style->relief.back;
 			bevel->lolo_color = GetShadow (style->relief.back);
 		}
-		bevel->hilo_color = GetAverage (style->relief.fore, style->relief.back);
+		bevel->hilo_color = GetAverage (bevel->hi_color, bevel->lo_color);
 #if 1
         if( !get_flags (hilite, NO_HILITE_OUTLINE) )
         {
-            if (get_flags (hilite, NORMAL_HILITE) )
+			if (get_flags (hilite, NORMAL_HILITE) )
             {
                 bevel->left_outline = bevel->top_outline = bevel->right_outline = bevel->bottom_outline = 1;
                 bevel->left_inline = bevel->top_inline =
-                    bevel->right_inline = bevel->bottom_inline = extra_hilite + 1;
+                    bevel->right_inline = bevel->bottom_inline = extra_hilite + get_flags( hilite, NO_HILITE_INLINE )?0:1;
             } else
             {
 #ifndef DONT_HILITE_PLAIN
                 bevel->left_inline = bevel->top_inline = bevel->right_inline = bevel->bottom_inline = extra_hilite;
 #endif
             }
-        }
+        }else if( get_flags( hilite, NO_HILITE_INLINE ) )
+			clear_flags( hilite, NO_HILITE_INLINE );
+
 #endif
         if (get_flags (hilite, LEFT_HILITE))
 		{
 			bevel->left_outline++;
-			bevel->left_inline++;
+			if( !get_flags( hilite, NO_HILITE_INLINE ) )
+				bevel->left_inline++;
             if( get_flags (hilite, NO_HILITE_OUTLINE) )
             {
                 bevel->left_outline++;
@@ -1209,45 +1239,51 @@ mystyle_make_bevel (MyStyle * style, ASImageBevel * bevel, int hilite, Bool reve
 		if (get_flags (hilite, TOP_HILITE))
 		{
 			bevel->top_outline++;
-			bevel->top_inline++;
+			if( !get_flags( hilite, NO_HILITE_INLINE ) )
+				bevel->top_inline++;
             if( get_flags (hilite, NO_HILITE_OUTLINE) )
                 bevel->top_inline += extra_hilite ;
         }
 		if (get_flags (hilite, RIGHT_HILITE))
 		{
 			bevel->right_outline++;
-			bevel->right_inline++;
+			if( !get_flags( hilite, NO_HILITE_INLINE ) )
+				bevel->right_inline++;
             if( get_flags (hilite, NO_HILITE_OUTLINE) )
                 bevel->right_inline += extra_hilite ;
 		}
 		if (get_flags (hilite, BOTTOM_HILITE))
 		{
 			bevel->bottom_outline++;
-			bevel->bottom_inline++;
+			if( !get_flags( hilite, NO_HILITE_INLINE ) )
+				bevel->bottom_inline++;
             if( get_flags (hilite, NO_HILITE_OUTLINE) )
                 bevel->bottom_inline += extra_hilite ;
         }
 /* experimental code */
 #if 1
-		if( bevel->top_outline > 1 ) 
+		if( !get_flags( hilite, NO_HILITE_INLINE ) )
 		{	
-			bevel->top_inline += bevel->top_outline - 1 ;
-			bevel->top_outline = 1 ;
-		}
-		if( bevel->left_outline > 1 ) 
-		{	
-			bevel->left_inline += bevel->left_outline - 1 ;
-			bevel->left_outline = 1 ;
-		}
-		if( bevel->right_outline > 1 ) 
-		{	
-			bevel->right_inline += bevel->right_outline - 1 ;
-			bevel->right_outline = 1 ;
-		}
-		if( bevel->bottom_outline > 1 ) 
-		{	
-			bevel->bottom_inline += bevel->bottom_outline - 1 ;
-			bevel->bottom_outline = 1 ;
+			if( bevel->top_outline > 1 ) 
+			{	
+				bevel->top_inline += bevel->top_outline - 1 ;
+				bevel->top_outline = 1 ;
+			}
+			if( bevel->left_outline > 1 ) 
+			{	
+				bevel->left_inline += bevel->left_outline - 1 ;
+				bevel->left_outline = 1 ;
+			}
+			if( bevel->right_outline > 1 ) 
+			{	
+				bevel->right_inline += bevel->right_outline - 1 ;
+				bevel->right_outline = 1 ;
+			}
+			if( bevel->bottom_outline > 1 ) 
+			{	
+				bevel->bottom_inline += bevel->bottom_outline - 1 ;
+				bevel->bottom_outline = 1 ;
+			}
 		}
 #endif
 	} else if (bevel)
